#!/usr/bin/env node

const inquirer = require('inquirer')
const path = require('path')
const { execSync } = require('child_process')

const QUESTIONS = [
    {
        name: 'project-name',
        type: 'input',
        message: 'Project name:',
        validate: function(input) {
            // Project name may only include letters, numbers, underscores and hashes.
            if (/^([A-Za-z\-\_\d])+$/.test(input)) {
                return true
            }

            return false
        },
    },
]

const repositoryUrl = `https://gitlab.com/monkkey/express-typescript`

inquirer.prompt(QUESTIONS).then(createProjectFromAnswers(repositoryUrl))

function createProjectFromAnswers(repositoryUrl) {
    return (answers) => {
        const projectName = answers['project-name']
        const projectPath = path.join(__dirname, projectName)
        cloneRepo(repositoryUrl, projectPath)
    }
}

function cloneRepo(repositoryUrl, targetPath) {
    try {
        execSync(`git clone ${repositoryUrl} ${targetPath}`)
        execSync(`rm -rf ${path.join(targetPath, '.git')}`)
    } catch (error) {
        execSync(`rm -rf ${targetPath}`)
    }
}
